# gcmai

Tired of not knowing what messages to use on your commits? Don't worry, I got you!



## Features


## Installation


### Prerequisites

- Python 3.7+
- `pip` (Python package installer)

### Local Installation

To install `gcmai` locally, clone the repository and run the following command:

```bash
pip install .
```


### Contrib

1. Clone this project
2. Run `pip install -e .`
  - Any modification won't need a re installation 

